@@ -341,7 +341,7 @@ class Table(object):
         
     _datetime_format = {}  # TODO: test the various RDBMS for power to read the standard
     def _prep_datum(self, datum, dialect, col):
-        if datum is None:
+        if datum is None or not str(datum).strip():
             return 'NULL'
         pytype = self.columns[col]['pytype']
         if pytype == datetime.datetime:
@@ -408,13 +408,18 @@ class Table(object):
             if self.varying_length_text:
                 col['satype'] = sa.Text()
             else:
+                str_len = max(len(col['sample_datum']), col['str_length'])
                 col['satype'] = sa.Unicode(len(col['sample_datum']))
         else:
             col['satype'] = self.types2sa[type(col['sample_datum'])]
+            if col['satype'] == sa.Integer and (
+                col['sample_datum'] > 2147483647 or col['sample_datum'] < -2147483647):
+                col['satype'] = sa.BigInteger
         return col
 
     types2sa = {datetime.datetime: sa.DateTime, int: sa.Integer,
-                float: sa.Numeric, bool: sa.Boolean}
+                float: sa.Numeric, bool: sa.Boolean,
+                type(None): sa.Text}
 
     def _determine_types(self):
         column_data = OrderedDict()
@@ -430,24 +435,28 @@ class Table(object):
             if not isinstance(row, OrderedDict):
                 keys = sorted(keys)
             for k in keys:
-                v = row[k]
-                if not th.is_scalar(v):
-                    v = str(v)
+                v_raw = row[k]
+                if not th.is_scalar(v_raw):
+                    v = str(v_raw)
                     self.comments[k] = 'nested values! example:\n%s' % \
                                        pprint.pformat(v)
                     logging.warning('in %s: %s' % (k, self.comments[k]))
-                v = th.coerce_to_specific(v)
+                v = th.coerce_to_specific(v_raw)
                 if k not in self.columns:
                     self.columns[k] = {'sample_datum': v,
+                                       'str_length': len(str(v_raw)),
                                        'is_nullable': not (rowcount == 1 and
-                                                           v is not None),
+                                                           v is not None and
+                                                           str(v).strip()
+                                                           ),
                                        'is_unique': set([v, ])}
                 else:
                     col = self.columns[k]
+                    col['str_length'] = max(col['str_length'], len(str(v_raw)))
                     old_sample_datum = col.get('sample_datum')
                     col['sample_datum'] = th.best_representative(
                         col['sample_datum'], v)
-                    if (v is None):
+                    if (v is None) or (not str(v).strip()):
                         col['is_nullable'] = True
                     if (col['is_unique'] != False):
                         if v in col['is_unique']:
